@@ -16,6 +16,7 @@ class WizardExecutionStep extends Component {
         this.ansibleFail = this.ansibleFail.bind(this)
         this.runAnsiblePlaybook = this.runAnsiblePlaybook.bind(this)
         this.callBack = this.callBack.bind(this)
+        this.runCleanUpPlaybook = this.runCleanUpPlaybook.bind(this)
     }
     componentDidMount() {
         this.runAnsiblePlaybook()
@@ -23,34 +24,61 @@ class WizardExecutionStep extends Component {
     ansibleDone() {
         this.setState({ ansibleStatus: 0 })
         let filePath = CONFIG_FILES.ansibleStatus
-        AnsibleUtil.handleDirAndFileCreation(filePath, String(this.state.ansibleStatus), function (result) {
-            console.log("Status File: ", result)
-        })
+        let fileContent = String(this.state.ansibleStatus)
+        this.saveDeploymentLog(filePath, fileContent, 1)
     }
     ansibleStdout(data) {
         this.setState({ ansibleLog: this.state.ansibleLog + data })
     }
     ansibleFail(response) {
       this.setState({ ansibleStatus: -1 })
+      const that = this;
       if(response.exit_status === 1) {
         this.ansibleStdout("ERROR! No inventory was parsed, please check your configuration and options. Could be problem in inventory file.")
       }
       let filePath = CONFIG_FILES.ansibleStatus
-      AnsibleUtil.handleDirAndFileCreation(filePath, String(this.state.ansibleStatus), function (result) {
-          console.log("Status File: ", result)
-      })
+      let fileContent = String(this.state.ansibleStatus)
+      this.saveDeploymentLog(filePath, fileContent, 1)
+      that.setState({ ansibleLog: that.state.ansibleLog + "Please check "+ CONFIG_FILES.glusterDeploymentLog +" for more informations." })
     }
     runAnsiblePlaybook() {
-        const that = this
-      AnsibleUtil.runAnsiblePlaybook(CONFIG_FILES.ansibleInventoryFile, this.ansibleStdout, this.ansibleDone, this.ansibleFail, function(response) {
-        that.setState({ ansibleStatus: 1 })
-        if(response === true){
-          that.ansibleDone()
-        } else {
-          that.ansibleFail(response)
-        }
+      const that = this
+      let filePath = CONFIG_FILES.ansibleInventoryFile
+      if(this.props.ansibleWizardType == "expand_volume") {
+        filePath = CONFIG_FILES.ansibleExpandVolumeInventoryFile
+      }
+      if(that.props.ansibleWizardType === "expand_cluster"){
+        AnsibleUtil.runExpandCluster(function(response) {
+          AnsibleUtil.runAnsiblePlaybook(that.props.isVerbosityEnabled, CONFIG_FILES.ansibleInventoryFile, that.ansibleStdout, that.ansibleDone, that.ansibleFail, function(response) {
+            that.setState({ ansibleStatus: 1 })
+            if(response === true){
+              that.ansibleDone()
+            } else {
+              that.ansibleFail(response)
+            }
+          })
+        })
+      } else {
+        AnsibleUtil.runAnsiblePlaybook(that.props.isVerbosityEnabled, filePath, that.ansibleStdout, that.ansibleDone, that.ansibleFail, function(response) {
+          that.setState({ ansibleStatus: 1 })
+          if(response === true){
+            that.ansibleDone()
+          } else {
+            that.ansibleFail(response)
+          }
+        })
+      }
+    }
+    runCleanUpPlaybook(){
+      const that = this;
+      this.state.ansibleLog = ""
+      AnsibleUtil.runAnsibleCleanupPlaybook(this.ansibleStdout, this.ansibleDone, this.ansibleFail, function(response) {
+        console.log("Cleanup playbook executed.");
+        that.setState({ ansibleLog: that.state.ansibleLog + "Please check "+ CONFIG_FILES.glusterDeploymentCleanUpLog +" for more informations." })
+        that.saveDeploymentLog(CONFIG_FILES.glusterDeploymentCleanUpLog, that.state.ansibleLog, 2)
       })
     }
+
     callBack() {
         if (this.props.ansibleWizardType === "setup") {
             this.props.onSuccess(
@@ -74,6 +102,15 @@ class WizardExecutionStep extends Component {
         ReactDOM.findDOMNode(this.ansibleLogText).scrollTop = maxScrollTop > 0 ? maxScrollTop : 0;
       }
     }
+    saveDeploymentLog(filePath, fileContent, n) {
+      const that = this;
+      if (n <= 2) {
+        AnsibleUtil.handleDirAndFileCreation(filePath, fileContent, function (result) {
+            console.log("Status File: ", result)
+            that.saveDeploymentLog(CONFIG_FILES.glusterDeploymentLog, that.state.ansibleLog, n+1)
+        })
+      }
+    }
     render() {
         if (this.state.ansibleStatus === 0) {
             return <SuccessPanel callBack={this.callBack} ansibleWizardType={this.props.ansibleWizardType} />
@@ -81,9 +118,7 @@ class WizardExecutionStep extends Component {
         return (
             <div className="col-sm-12">
                 <div className="panel panel-default">
-                    <div className="panel-heading">
-                        <Status status={this.state.ansibleStatus} reDeployCallback={this.props.reDeployCallback}/>
-                    </div>
+                        <Status status={this.state.ansibleStatus} reDeployCallback={this.props.reDeployCallback} runCleanUpPlaybook={this.runCleanUpPlaybook}/>
                     <div className="list-group">
                         <div className="list-group-item">
                             <textarea className="ansible-wizard-config-preview"
@@ -103,7 +138,7 @@ WizardExecutionStep.propTypes = {
     reDeployCallback: PropTypes.func.isRequired
 }
 
-const Status = ({ status, reDeployCallback }) => {
+const Status = ({ status, reDeployCallback, runCleanUpPlaybook}) => {
     let msg = "Deployment in progress"
     let statusIcon = <div className="spinner spinner-lg blank-slate-pf-icon"></div>
     if (status === -1) {
@@ -111,15 +146,20 @@ const Status = ({ status, reDeployCallback }) => {
         statusIcon = <span className="pficon-error-circle-o"></span>
     }
     return (
-        <div>
+        <div className="panel-heading">
             {statusIcon}
             <span>{msg}</span>
             <div className="pull-right">
                 {status === -1 &&
-                    <button className="btn btn-primary" onClick={reDeployCallback}>
+                  <div>
+                     <button className="btn btn-primary" onClick={runCleanUpPlaybook}>
+                        CleanUp
+                     </button> &nbsp;
+                     <button className="btn btn-primary" onClick={reDeployCallback}>
                         <span className="pficon pficon-restart">&nbsp;</span>
                         Redeploy
                      </button>
+                  </div>
                 }
             </div>
         </div>
@@ -133,6 +173,8 @@ const SuccessPanel = ({ callBack, ansibleWizardType }) => {
         message = "Successfully deployed Gluster"
     } else if (ansibleWizardType === "expand_cluster") {
         message = "Successfully expanded cluster"
+    } else if (ansibleWizardType === "expand_volume") {
+        message = "Successfully expanded volume"
     } else {
         message = "Successfully created volume"
     }
@@ -151,6 +193,10 @@ const SuccessPanel = ({ callBack, ansibleWizardType }) => {
             <h5 className="blank-slate-pf-main-action">
                 {message}
             </h5>
+            { ansibleWizardType === "expand_volume" && <h5 className="blank-slate-pf-main-action">
+                  Please run rebalance on the volume expanded.
+                </h5>
+            }
             <button type="button" className="btn btn-lg btn-primary"
                 onClick={callBack}>
                 {buttonLabel}
