@@ -13,13 +13,15 @@ class WizardPreviewStep extends Component {
             ansibleConfig: "",
             isEditing: false,
             isChanged: false,
-            ansibleFileGenerated: false
+            ansibleFileGenerated: false,
+            isVerbosityEnabled: false
         }
         this.handleConfigChange = this.handleConfigChange.bind(this)
         this.handleEdit = this.handleEdit.bind(this)
         this.handleSave = this.handleSave.bind(this)
         this.readAnsibleConfig = this.readAnsibleConfig.bind(this)
-        this.createAnsibleConfig = this.createAnsibleConfig.bind(this)
+
+        this.handleVerbosity = this.handleVerbosity.bind(this)
     }
     createAnsibleConfig() {
         if (this.props.glusterModel.volumes.length > 0 && this.props.glusterModel.hosts.length > 0) {
@@ -28,6 +30,9 @@ class WizardPreviewStep extends Component {
                 isChanged: false
             })
             const that = this
+            if (that.props.ansibleWizardType === "expand_cluster") {
+              AnsibleUtil.createExpandClusterConfig(that.props.glusterModel, CONFIG_FILES.expandClusterConfigFilePath)
+            }
             AnsibleUtil.createAnsibleConfig(that.props.glusterModel,
                 CONFIG_FILES.ansibleInventoryFile,
                 that.props.ansibleWizardType,
@@ -47,7 +52,13 @@ class WizardPreviewStep extends Component {
     readAnsibleConfig() {
         const that = this
         this.setState({ ansibleConfig: "Loading Ansible configuration..." })
-        cockpit.file(CONFIG_FILES.ansibleInventoryFile).read()
+        let filePath = CONFIG_FILES.ansibleInventoryFile
+        if(this.props.ansibleWizardType == "expand_volume") {
+          filePath = CONFIG_FILES.ansibleExpandVolumeInventoryFile
+        } else {
+          filePath = CONFIG_FILES.ansibleInventoryFile
+        }
+        cockpit.file(filePath).read()
         .done(function(ansibleConfig) {
             that.setState({ ansibleConfig })
         })
@@ -87,6 +98,8 @@ class WizardPreviewStep extends Component {
                 }
               }
             }
+        } else if(nextProps.ansibleWizardType === "expand_volume" && nextProps.activeStep !== 3) {
+          this.setState({ ansibleFileGenerated: false})
         }
       }
       if(!this.state.ansibleFileGenerated && (!this.state.isChanged || !this.props.isDeploymentStarted)) {
@@ -127,6 +140,9 @@ class WizardPreviewStep extends Component {
                 }
               }
             }
+        } else if(nextProps.ansibleWizardType === "expand_volume" && nextProps.activeStep == 3) {
+          this.createAnsibleConfig()
+          this.setState({ ansibleFileGenerated: true })
         }
       }
     }
@@ -143,9 +159,31 @@ class WizardPreviewStep extends Component {
     }
     handleSave() {
         this.setState({ isEditing: false })
-        AnsibleUtil.writeConfigFile(CONFIG_FILES.ansibleInventoryFile, this.state.ansibleConfig, function (result) {
+        let filePath = CONFIG_FILES.ansibleInventoryFile
+        if(this.props.ansibleWizardType == "expand_volume") {
+          filePath = CONFIG_FILES.ansibleExpandVolumeInventoryFile
+        } else {
+          filePath = CONFIG_FILES.ansibleInventoryFile
+        }
+        AnsibleUtil.writeConfigFile(filePath, this.state.ansibleConfig, function (result) {
             console.log("Result after editing and saving config file: ", result)
         })
+        if(this.props.ansibleWizardType === "expand_cluster") {
+          AnsibleUtil.createExpandClusterConfig(this.props.glusterModel, this.props.expandClusterConfigFilePath, function (result) {
+              console.log("Result after editing and saving ExpandClusterConfigFile: ", result);
+          })
+        }
+    }
+    handleVerbosity(value) {
+      if(value) {
+        this.setState({
+          isVerbosityEnabled: true
+        })
+      } else {
+        this.setState({
+          isVerbosityEnabled: false
+        })
+      }
     }
     render() {
         if (this.props.isDeploymentStarted) {
@@ -157,6 +195,7 @@ class WizardPreviewStep extends Component {
                     reDeployCallback={this.props.reDeployCallback}
                     ansibleWizardType={this.props.ansibleWizardType}
                     expandClusterConfigFilePath={this.props.expandClusterConfigFilePath}
+                    isVerbosityEnabled={this.state.isVerbosityEnabled}
                     />
             )
         } else {
@@ -165,9 +204,14 @@ class WizardPreviewStep extends Component {
                     <div className="panel panel-default">
                         <div className="panel-heading">
                             <span className="pficon-settings"></span>
-                            <span>
+                            {this.props.ansibleWizardType == "expand_volume" && <span>
+                                Generated Ansible inventory : {CONFIG_FILES.ansibleExpandVolumeInventoryFile}
+                              </span>
+                            }
+                            {this.props.ansibleWizardType !== "expand_volume" && <span>
                                 Generated Ansible inventory : {CONFIG_FILES.ansibleInventoryFile}
-                            </span>
+                              </span>
+                            }
                             <div className="pull-right">
                                 {this.state.isEditing &&
                                     <button className="btn btn-default"
@@ -194,6 +238,13 @@ class WizardPreviewStep extends Component {
                             value={this.state.ansibleConfig} onChange={this.handleConfigChange} readOnly={!this.state.isEditing}>
                         </textarea>
                     </div>
+                    <div id="debug-toggle" className="verbosity">
+                        <input type="checkbox" title= "Ansible playbook will be executed with -vv option."
+                            checked={this.state.isVerbosityEnabled}
+                            onChange={(e) => this.handleVerbosity(e.target.checked)}
+                            />
+                        <label className="control-label">Enable Debug Logging</label>
+                    </div>
                 </div>
             )
         }
